# G4RZK
Sebuah module packages yang biasa di pakai buat anu ea, ytta

## List Module
 *  re
 *  os
 *  sys
 *  json
 *  time
 *  inquirer
 *  random
 *  calendar
 *  requests
 
 * from datetime import date
 * from datetime import datetime
 * from bs4 import BeautifulSoup as parser
 * from concurrent.futures import ThreadPoolExecutor

 * from rich.tree import Tree
 * from rich.panel import Panel
 * from rich import print as iprint
 * from rich.progress import track

## String Date Time
```python
from g4rzk.module import *

ct = datetime.now()
n = ct.month
bulan =  ["Januari", "Februari", "Maret", "April", "Mei", "Juni", "Juli", "Agustus", "September", "Oktober", "November", "Desember"]
try:
	if n < 0 or n > 12:
		exit()
	nTemp = n - 1
except ValueError:
	exit()

current = datetime.now()
tahun = current.year
bu = current.month
hari = current.day
bulan = bulan[nTemp]

my_date = date.today()
hr = calendar.day_name[my_date.weekday()]
cv_hr = {"Sunday":"Minggu", "Monday":"Senin", "Tuesday":"Selasa", "Wednesday":"Rabu", "Thursday":"Kamis", "Friday":"Jumat", "Saturday":"Sabtu"}

nama_hari = cv_hr[hr]
tgl = (f"{hari}-{bulan}-{tahun}")
tanggal = (f"{nama_hari}-{hari}-{bulan}-{tahun}")
bulan_ttl = {"01": "Januari", "02": "Februari", "03": "Maret", "04": "April", "05": "Mei", "06": "Juni", "07": "Juli", "08": "Agustus", "09": "September", "10": "Oktober", "11": "November", "12": "Desember"}

now = datetime.now()
hour = now.hour
if hour < 4:
	waktu = "Selamat Dini Hari"
elif 4 <= hour < 12:
	waktu = "Selamat Pagi"
elif 12 <= hour < 15:
	waktu = "Selamat Siang"
elif 15 <= hour < 17:
	waktu = "Selamat Sore"
else:
	waktu = "Selamat Malam"
```

## String Color Python
```python
BLACK = "\033[0;30m"
RED = "\033[0;31m"
GREEN = "\033[0;32m"
BROWN = "\033[0;33m"
BLUE = "\033[0;34m"
PURPLE = "\033[0;35m"
CYAN = "\033[0;36m"
LIGHT_GRAY = "\033[0;37m"
DARK_GRAY = "\033[1;30m"
LIGHT_RED = "\033[1;31m"
LIGHT_GREEN = "\033[1;32m"
YELLOW = "\033[1;33m"
LIGHT_BLUE = "\033[1;34m"
LIGHT_PURPLE = "\033[1;35m"
LIGHT_CYAN = "\033[1;36m"
LIGHT_WHITE = "\033[1;37m"
BOLD = "\033[1m"
FAINT = "\033[2m"
ITALIC = "\033[3m"
UNDERLINE = "\033[4m"
BLINK = "\033[5m"
NEGATIVE = "\033[7m"
CROSSED = "\033[9m"
END = "\033[0m"
```